#include "nsIFactory.h"
#include "nsISupports.h"
#include "csIPlugin.h"
#include "csIAuthentication.h"

#include "csAuthentication.h"

// interfaces
static NS_DEFINE_IID(kISupportsIID,         NS_ISUPPORTS_IID);
static NS_DEFINE_IID(kIFactoryIID,          NS_IFACTORY_IID);
static NS_DEFINE_IID(kIPluginIID,           CS_IPLUGIN_IID);
static NS_DEFINE_IID(kIAuthenticationIID,   CS_IAUTHENTICATION_IID);

// implementations
static NS_DEFINE_IID(kCAuthentication,  CS_IAUTHENTICATION_CID);

class csAuthenticationFactory : public nsIFactory
{   
  public:   
    // nsISupports methods   
    NS_IMETHOD QueryInterface(const nsIID &aIID,    
                              void **aResult);   
    NS_IMETHOD_(nsrefcnt) AddRef(void);   
    NS_IMETHOD_(nsrefcnt) Release(void);   

    // nsIFactory methods   
    NS_IMETHOD CreateInstance(nsISupports *aOuter,   
                              const nsIID &aIID,   
                              void **aResult);   

    NS_IMETHOD LockFactory(PRBool aLock);   

    csAuthenticationFactory(const nsCID &aClass);   
    ~csAuthenticationFactory();   

  private:   
    nsrefcnt  mRefCnt;   
    nsCID     mClassID;
};   

csAuthenticationFactory::csAuthenticationFactory(const nsCID &aClass)   
{   
  mRefCnt = 0;
  mClassID = aClass;
}   

csAuthenticationFactory::~csAuthenticationFactory()   
{   
  NS_ASSERTION(mRefCnt == 0, "non-zero refcnt at destruction");   
}   

nsresult csAuthenticationFactory::QueryInterface(const nsIID &aIID,   
                                                 void **aResult)   
{   
  if (aResult == NULL) {   
    return NS_ERROR_NULL_POINTER;   
  }   

  // Always NULL result, in case of failure   
  *aResult = NULL;   

  if (aIID.Equals(kISupportsIID)) {   
    *aResult = (void *)(nsISupports*)this;   
  } else if (aIID.Equals(kIFactoryIID)) {   
    *aResult = (void *)(nsIFactory*)this;   
  }   

  if (*aResult == NULL) {   
    return NS_NOINTERFACE;   
  }   

  AddRef(); // Increase reference count for caller   
  return NS_OK;   
}   

nsrefcnt csAuthenticationFactory::AddRef()   
{   
  return ++mRefCnt;   
}   

nsrefcnt csAuthenticationFactory::Release()   
{   
  if (--mRefCnt == 0) {   
    delete this;   
    return 0; // Don't access mRefCnt after deleting!   
  }   
  return mRefCnt;   
}  

nsresult csAuthenticationFactory::CreateInstance(nsISupports *aOuter,  
                                                 const nsIID &aIID,  
                                                 void **aResult)  
{  
  (nsISupports*) aOuter;

  if (aResult == NULL) {  
    return NS_ERROR_NULL_POINTER;  
  }  

  *aResult = NULL;  
  
  nsISupports *inst = NULL;

  if (mClassID.Equals(kCAuthentication) || mClassID.Equals(kIAuthenticationIID)) {
    inst = (nsISupports *)(csIAuthentication*)new csAuthentication();
  } else if (mClassID.Equals(kIPluginIID)) {
    inst = (nsISupports *)(csIPlugin*)new csAuthentication();
  }

  if (inst == NULL) {  
    return NS_ERROR_OUT_OF_MEMORY;  
  }  

  nsresult res = inst->QueryInterface(aIID, aResult);

  if (res != NS_OK) {  
    // We didn't get the right interface, so clean up  
    delete inst;  
  }  

  return res;  
}  

nsresult csAuthenticationFactory::LockFactory(PRBool aLock)  
{  
  // Not implemented in simplest case.  
  (PRBool) aLock;
  return NS_OK;
}  

// return the proper factory to the caller
extern "C" NS_EXPORT nsresult NSGetFactory(const nsCID &aClass, 
                                           nsISupports* aServiceMgr,
                                           nsIFactory **aFactory)
{
  (nsISupports*) aServiceMgr;

  if (NULL == aFactory) {
    return NS_ERROR_NULL_POINTER;
  }

  *aFactory = new csAuthenticationFactory(aClass);

  if (NULL == aFactory) {
    return NS_ERROR_OUT_OF_MEMORY;
  }

  return (*aFactory)->QueryInterface(kIFactoryIID, (void**)aFactory);
}

